# Liveramp clean room
This library provides high level functions for interacting with liveramp's clean room API. Whilst users can directly interact with the API, we highly recommend the use of this client as it provides the following benefits:
- Automatic fetching and efficient caching of access token
- Automatic fetching of query status with exponential backoff
- Provides a simple interface for fetching query result as a pandas dataframe
- Provides user friendly interfaces for interacting with assets and associated permissions
- Provides clear and intuitive error messages


## Pre-Requisites


### Credentials File


Use of the client requires an account configured with access to an organization within Data Hub. LiveRamp customers must use a service account for that purpose. A service account credential, in the form of a JSON file, can be generated by a LiveRamp employee and shared securely.


### Installation


The Client is hosted on https://pypi.org/project/liveramp-clean-room/ and thus can be installed via


```bash
pip install liveramp_clean_room
```


Once installed the client be instantiated and added to your code as the example below shows:


```python
from liveramp_clean_room import datahub


## Initialize a client
org_id = "00XXX0XXX0XXX00X0XXX000XXX"
credentials_file = "Path to service account file"
client = datahub.Client(org_id, credentials_file)
```
Where `org_id` is the id of an organization within DataHub and `credentials_file` is the JSON file location of your service account


## Running Queries


To run a query utilize the run_query function. DataHub supports the following query types:


- Data Manipulation Language (DML)


    `SELECT query`


- Data Definition Language (DDL)


    `CREATE OR REPLACE FUNCTION/DROP FUNCTION)`, used to create or drop UDFs, a createdAssetID will be returned in the response. 


Example: Run a query and get results
---
```python
from liveramp_clean_room import datahub


org_id = "00XXX0XXX0XXX00X0XXX000XXX"
credentials_file = "Path to service account file"
client = datahub.Client(org_id, credentials_file)
query_id = client.run_query("select * from schema.mytable")


## Fetch result as a pandas dataframe
dataframe = client.get_result(query_id)
```


> Note that the client returns a Pandas Dataframe

